tests.test_compare module — pydevDAG 1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- tests »
- tests package »

# tests.test_compare module

## tests.test_compare

Tests graph comparison.

class `tests.test_compare.` `TestGraphComparison`

  Bases: `object`

  Compare storage graphs more or less stringently.

  `test_equal`(tmpdir)

    Verify that two identical graphs are equivalent.

class `tests.test_compare.` `TestGraphDifference`

  Bases: `object`

  Test ability to find differences among graphs.

  `EDGE_MATCHER` = <pydevDAG._compare.Matcher object at 0x7fa3c13888d0>
  `NODE_MATCHER` = <pydevDAG._compare.Matcher object at 0x7fa3c1388550>
  `test_empty`()

    Verify that one graph and an empty graph have the correct differences.

  `test_equal`(tmpdir)

    Verify that two identical graphs are equivalent.

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- tests »
- tests package »